summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/pipeline.h
diff options
context:
space:
mode:
authorMark Benvenuto <mark.benvenuto@mongodb.com>2014-05-19 12:46:52 -0400
committerMark Benvenuto <mark.benvenuto@mongodb.com>2014-05-19 14:43:05 -0400
commitf2bfd36a6f3eb7e7e2587268be3cc12636703d42 (patch)
tree6436772fbceb28f07bbfaee528d700159beb0cec /src/mongo/db/pipeline/pipeline.h
parentc10e8282a7af38f8512e911a14889e14df8a2c6a (diff)
downloadmongo-f2bfd36a6f3eb7e7e2587268be3cc12636703d42.tar.gz
SERVER-13256: Remove pch - qualify std in headers
Diffstat (limited to 'src/mongo/db/pipeline/pipeline.h')
-rw-r--r--src/mongo/db/pipeline/pipeline.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mongo/db/pipeline/pipeline.h b/src/mongo/db/pipeline/pipeline.h
index 4d11f8eed29..297d73874f9 100644
--- a/src/mongo/db/pipeline/pipeline.h
+++ b/src/mongo/db/pipeline/pipeline.h
@@ -57,15 +57,15 @@ namespace mongo {
* @returns the pipeline, if created, otherwise a NULL reference
*/
static intrusive_ptr<Pipeline> parseCommand(
- string& errmsg,
+ std::string& errmsg,
const BSONObj& cmdObj,
const intrusive_ptr<ExpressionContext>& pCtx);
/// Helper to implement Command::addRequiredPrivileges
static void addRequiredPrivileges(Command* commandTemplate,
- const string& dbname,
+ const std::string& dbname,
BSONObj cmdObj,
- vector<Privilege>* out);
+ std::vector<Privilege>* out);
intrusive_ptr<ExpressionContext> getContext() const { return pCtx; }
@@ -122,10 +122,10 @@ namespace mongo {
bool canRunInMongos() const;
/**
* Write the pipeline's operators to a vector<Value>, with the
* explain flag true (for DocumentSource::serializeToArray()).
*/
- vector<Value> writeExplainOps() const;
+ std::vector<Value> writeExplainOps() const;
/**
* Returns the dependencies needed by this pipeline.
@@ -122,10 +122,10 @@ namespace mongo {
bool canRunInMongos() const;
/**
- * Write the pipeline's operators to a vector<Value>, with the
+ * Write the pipeline's operators to a std::vector<Value>, with the
* explain flag true (for DocumentSource::serializeToArray()).
*/